#
# spec file for package kubeconform
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubeconform
Version:        0.6.6
Release:        1.1
Summary:        A fast Kubernetes manifests validator, with support for custom resources
License:        Apache-2.0
URL:            https://github.com/yannh/kubeconform/
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Kubeconform is a Kubernetes manifests validation tool. It is inspired by, contains
code from and is designed to stay close to Kubeval, but with the following
improvements:

- high performance: will validate & download manifests over multiple routines, caching
  downloaded files in memory
- configurable list of remote, or local schemas locations, enabling validating Kubernetes
  custom resources (CRDs) and offline validation capabilities
- uses by default a self-updating fork of the schemas registry maintained by the
  kubernetes-json-schema project - which guarantees up-to-date schemas for all recent versions
  of Kubernetes.

%prep
%autosetup -a1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/ .../.

%install
install -D -m 0755 ./bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%{_bindir}/%{name}
%license LICENSE
%doc Readme.md

%changelog
* Fri May 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.6:
  * fix go.mod
* Thu May  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.5:
  * Slightly improve the coverage of the validator test (#271)
  * Stop validating output of closed channel in Validate (#265)
  * Update go version in go.mod (#269)
  * Update Go & Base images (#268)
  * Remove deprecated Maintainer tag in Dockerfile (#267)
  * Sanitize csv strings (#258)
  * Update `kubeconform -h` output (#260)
  * Fix junit output, also ensure junit output is deterministic
    (#253)
  * Fail early on incorrect version of k8s (#254)
  * Update GH actions and goreleaser (#252)
  * Update Golang to 1.21.4 (#245)
* Wed Apr  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.6.4:
  * Update Golang to 1.21.4
  * openapi2jsonschema.py now correctly fails if no FILE is passed
    (#244)
  * Update Readme.md (#232)
  * Update Go and Goreleaser to 1.20, update dependencies (#231)
  * Avoid unnecessary type conversions (#222)
  * Force Draft version of JsonSchema (#221)
* Sun Sep 17 2023 jkowalczyk@suse.com
- Update to version 0.6.3:
  * Add test validating using CRD that misses explicit draft version
  * Force Draft version of JsonSchema
  * Update Readme.md to add `fullgroup` explanation (#220)
  * Fix #130 in a backward-compatible way (#219)
  * Update Readme.md
  * fix: add missing output formats in error message (#213)
* Sun Sep 17 2023 jkowalczyk@suse.com
- Update to version 0.6.2:
  * Fix for 196: Multi-architecture image (#204)
  * Fix anchored link on Readme.md (#205)
  * Revert "Add support for Arm64 Docker images (#201)"
  * Add support for Arm64 Docker images (#201)
  * Move cfg parsing out of realmain, rename realmain to kubeconform
  * Add JSON/YAML annotations to Config struct
  * Do not hardcode output stream in pkg/output
  * Add support for "pretty" output (#195)
  * docs: Add winget as installation method on Windows (#192)
  * Fix CI badge image (#184)
* Sun Sep 17 2023 jkowalczyk@suse.com
- _service change disabled to manual per osc deprecation warning:
  WARNING: Command 'disabledrun/dr' is obsolete, please convert
  your _service to use 'manual' and then 'manualrun/mr' instead.
* Mon Mar 27 2023 andrea.manzini@suse.com
- Update to version 0.6.1:
  * fix: expose error instance path instead of schema path
  * support disabling ssl validation in openapi2jsonschema.py
  * Try to expose JSON paths
  * feat: support to set an alternative image owner
  * Documenting Helm support via 3rd party repo
  * Update LICENSE
  * Add opencontainers label
  * Add informations how to use Kubeconform in Gitlab-CI
* Mon Dec 12 2022 rombert@apache.org
- Update to version 0.5.0:
  * Allow to skip resources using the GVK notation (#92)
  * Update goreleaser (#137)
  * Do not expose internal CPU profiling option as flag (#136)
  * Validate JUnit output against Jenkins JUnit XSD (#134)
  * Add debug information to help understand failures finding schemas (#133)
  * Update fixture file to use no hash function
  * Upgrade hash to sha256. (#126)
  * remove link to dead project (#125)
  * add {{ .Group }} variable to schema location options (#120)
  * Forbid duplicate keys in strict mode (#121)
  * fix: change flag parse error handling to return errors instead of exiting (#107)
  * Adds info about installation via built in Go package manger (#116)
  * Fix grammar in  README.md (#114)
  * add constructor to handle equal sign (=) (#104)
  * chore: print the url of failed download (#96)
  * remove accidentally commited binary
  * Improve handling of cmdline errors (#91)
  * Minor css updates
  * Update website
  * Add cname to website
  * Publish site
  * Fixes acceptance test with new TAP output
  * feat(output/tap): Output qualified resource name
  * add horizontal line
  * set hero image width
  * scripts: Add tests for options
  * scripts: Optionally disallow additionalProperties at the root
  * Update Readme.md
  * Move version to main package
  * Update README
  * Add -v to output version number
  * Fix broken release notes
* Tue Oct 19 2021 Robert Munteanu <rombert@apache.org>
- Initial package
